<?php
/**
 * About configuration
 *
 * @package Bizhunt
 */

$config = array(
	'menu_name' => esc_html__( 'Bizhunt Setup', 'bizhunt' ),
	'page_name' => esc_html__( 'Bizhunt Setup', 'bizhunt' ),

	/* translators: theme version */
	'welcome_title' => sprintf( esc_html__( 'Welcome to %s - ', 'bizhunt' ), 'Bizhunt' ),

	/* translators: 1: theme name */
	'welcome_content' => sprintf( esc_html__( 'We hope this page will help you to setup %1$s with few clicks. We believe you will find it easy to use and perfect for your website development.', 'bizhunt' ), 'Bizhunt' ),

	// Quick links.
	'quick_links' => array(
		'theme_url' => array(
			'text' => esc_html__( 'Theme Details','bizhunt' ),
			'url'  => 'https://www.codeglim.com/downloads/bizhunt-multipurpose-business-wordpress-theme/',
		),
		'demo_url' => array(
			'text' => esc_html__( 'View Demo','bizhunt' ),
			'url'  => 'https://codeglim.com/bizhunt',
		),
		'documentation_url' => array(
			'text'   => esc_html__( 'Documentation','bizhunt' ),
			'url'    => 'https://justwpthemes.com/wp-content/uploads/2018/10/bizhunt-pro.docx',
		),
		'upgrade_url' => array(
			'text'   => esc_html__( 'Upgrade to Pro','bizhunt' ),
			'url'    => 'https://justwpthemes.com/downloads/bizhunt-pro/',
			'button' => 'primary'
		),
	),

	// Tabs.
	'tabs' => array(
		'getting_started'     => esc_html__( 'Getting Started', 'bizhunt' ),
		'recommended_actions' => esc_html__( 'Recommended Actions', 'bizhunt' ),
		'support'             => esc_html__( 'Support', 'bizhunt' ),
	),

	// Getting started.
	'getting_started' => array(
		array(
			'title'               => esc_html__( 'Theme Documentation', 'bizhunt' ),
			'text'                => esc_html__( 'Find step by step instructions to setup theme easily.', 'bizhunt' ),
			'button_label'        => esc_html__( 'View documentation', 'bizhunt' ),
			'button_link'         => 'https://justwpthemes.com/wp-content/uploads/2018/10/bizhunt-pro.docx',
			'is_button'           => true,
			'recommended_actions' => false,
			'is_new_tab'          => true,
		),
		array(
			'title'               => esc_html__( 'Recommended Actions', 'bizhunt' ),
			'text'                => esc_html__( 'We recommend few steps to take so that you can get complete site like shown in demo.', 'bizhunt' ),
			'button_label'        => esc_html__( 'Check recommended actions', 'bizhunt' ),
			'button_link'         => esc_url( admin_url( 'themes.php?page=bizhunt-about&tab=recommended_actions' ) ),
			'is_button'           => true,
			'recommended_actions' => false,
			'is_new_tab'          => false,
		),
		array(
			'title'               => esc_html__( 'Customize Everything', 'bizhunt' ),
			'text'                => esc_html__( 'Start customizing every aspect of the website with customizer.', 'bizhunt' ),
			'button_label'        => esc_html__( 'Go to Customizer', 'bizhunt' ),
			'button_link'         => esc_url( wp_customize_url() ),
			'is_button'           => true,
			'recommended_actions' => false,
			'is_new_tab'          => false,
		),
	),

	// Recommended actions.
	'recommended_actions' => array(
		'content' => array(
			'front-page' => array(
				'title'       => esc_html__( 'Setting Static Front Page','bizhunt' ),
				'description' => esc_html__( 'Create a new page to display on front page ( Ex: Bizhunt ) and assign "Bizhunt" template. Select A static page then Front page and Posts page to display front page specific sections. Note: Static page will be set automatically when you import demo content.', 'bizhunt' ),
				'id'          => 'front-page',
				'check'       => ( 'page' === get_option( 'show_on_front' ) ) ? true : false,
				'help'        => '<a href="' . esc_url( wp_customize_url() ) . '?autofocus[section]=static_front_page" class="button button-secondary">' . esc_html__( 'Static Front Page', 'bizhunt' ) . '</a>',
			),
			'newsletter' => array(
				'title'       => esc_html__( 'NewsLetter Plugin', 'bizhunt' ),
				'description' => esc_html__( 'Please install the Newsletter Plugin Before Importing Demo.', 'bizhunt' ),
				'check'       => class_exists( 'OCDI_Plugin' ),
				'plugin_slug' => 'newsletter',
				'id'          => 'newsletter',
			),
			'one-click-demo-import' => array(
				'title'       => esc_html__( 'One Click Demo Import', 'bizhunt' ),
				'description' => esc_html__( 'Please install the One Click Demo Import plugin to import the demo content. After activation go to Appearance >> Import Demo Data and import it.', 'bizhunt' ),
				'check'       => class_exists( 'OCDI_Plugin' ),
				'plugin_slug' => 'one-click-demo-import',
				'id'          => 'one-click-demo-import',
			),
		),
	),

	// Support.
	'support_content' => array(
		'first' => array(
			'title'        => esc_html__( 'Contact Support', 'bizhunt' ),
			'icon'         => 'dashicons dashicons-sos',
			'text'         => esc_html__( 'If you have any problem, feel free to create ticket on our dedicated Support forum.', 'bizhunt' ),
			'button_label' => esc_html__( 'Contact Support', 'bizhunt' ),
			'button_link'  => esc_url( 'https://www.codeglim.com/downloads/bizhunt-multipurpose-business-wordpress-theme/' ),
			'is_button'    => true,
			'is_new_tab'   => true,
		),
		'second' => array(
			'title'        => esc_html__( 'Theme Documentation', 'bizhunt' ),
			'icon'         => 'dashicons dashicons-book-alt',
			'text'         => esc_html__( 'Kindly check our theme documentation for detailed information and video instructions.', 'bizhunt' ),
			'button_label' => esc_html__( 'View Documentation', 'bizhunt' ),
			'button_link'  => 'https://justwpthemes.com/wp-content/uploads/2018/10/bizhunt-pro.docx',
			'is_button'    => true,
			'is_new_tab'   => true,
		),
		'third' => array(
			'title'        => esc_html__( 'Customization Request', 'bizhunt' ),
			'icon'         => 'dashicons dashicons-admin-tools',
			'text'         => esc_html__( 'This is 100% free theme and has premium version.Either Upgrade to Pro or  Feel free to contact us any time if you need any customization service.', 'bizhunt' ),
			'button_label' => esc_html__( 'Upgrade to Pro', 'bizhunt' ),
			'button_link'  => 'https://justwpthemes.com/downloads/bizhunt-pro/',
			'is_button'    => true,
			'is_new_tab'   => true,
		),
	),


);
Bizhunt_About::init( apply_filters( 'bizhunt_about_filter', $config ) );