<?php 

/**
 * Adds bizhunt_widget widget.
 */
class bizhunt_widget extends WP_Widget {

	/**
	 * Register widget with WordPress.
	 */
	function __construct() {
		parent::__construct(
			'bizhunt_widget', // Base ID
			esc_html__( 'Widget Title', 'bizhunt' ), // Name
			array( 'description' => esc_html__( 'A Bizhunt Widget Recent Post', 'bizhunt' ), ) // Args
		);
	}

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {
		echo $args['before_widget'];
		if ( ! empty( $instance['title'] ) ) {
		}

		?>
		<div class="single-footer">
			<h2 class="heading"><?php echo esc_html(  $instance['title'] ); ?></h2>
			<p><?php echo esc_html(  $instance['content'] ); ?></p>
			<div class="contact">
				<p class="location"><i class="fa fa-map-marker" aria-hidden="true"></i><?php echo esc_html(  $instance['location'] ); ?></p>
				<p class="mail-add"><i class="fa fa-envelope-o" aria-hidden="true"></i><a href="mailto:<?php echo esc_attr($instance['mail']); ?>"><?php echo esc_html(  $instance['mail'] ); ?></a></p>
				<p class="call"><i class="fa fa-phone-square" aria-hidden="true"></i><?php echo esc_html(  $instance['contact'] ); ?></p>
			</div>
		</div>
		<?php
		echo $args['after_widget'];
	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {
		$title = ! empty( $instance['title'] ) ? $instance['title'] : esc_html__( 'Office Address', 'bizhunt' );
		$content = ! empty( $instance['content'] ) ? $instance['content'] : esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, consectetur Lorem ipsum dolor sit amet, consectetur adipisicing elit, consec adipisicing elit,', 'bizhunt' );
		$location = ! empty( $instance['location'] ) ? $instance['location'] : esc_html__( 'Lakshmipur,1280 BD', 'bizhunt' );
		$mail = ! empty( $instance['mail'] ) ? $instance['mail'] : esc_html__( 'info@yourmail.com', 'bizhunt' );
		$contact = ! empty( $instance['contact'] ) ? $instance['contact'] : esc_html__( 'call:900-200-2315', 'bizhunt' );

		
		?>
		<p>
			<!-- Widget Title -->
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_attr_e( 'Title:', 'bizhunt' ); ?></label> 
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
			
			<!-- Widget Content -->
			<label for="<?php echo esc_attr( $this->get_field_id( 'content' ) ); ?>"><?php esc_attr_e( 'Content:', 'bizhunt' ); ?></label> 
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'content' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'content' ) ); ?>" type="text" value="<?php echo esc_attr( $content ); ?>">

			<!-- Widget Location -->
			<label for="<?php echo esc_attr( $this->get_field_id( 'location' ) ); ?>"><?php esc_attr_e( 'Location:', 'bizhunt' ); ?></label> 
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'location' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'location' ) ); ?>" type="text" value="<?php echo esc_attr( $location ); ?>">

			<!-- Widget Mail -->
			<label for="<?php echo esc_attr( $this->get_field_id( 'mail' ) ); ?>"><?php esc_attr_e( 'Mail:', 'bizhunt' ); ?></label> 
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'mail' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'mail' ) ); ?>" type="text" value="<?php echo esc_attr( $mail ); ?>">
			
			<!-- Widget Contact -->
			<label for="<?php echo esc_attr( $this->get_field_id( 'contact' ) ); ?>"><?php esc_attr_e( 'Contact:', 'bizhunt' ); ?></label> 
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'contact' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'contact' ) ); ?>" type="text" value="<?php echo esc_attr( $contact ); ?>">
			


		</p>
		<?php 
	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? sanitize_text_field( $new_instance['title'] ) : '';
		$instance['content'] = ( ! empty( $new_instance['content'] ) ) ? sanitize_text_field( $new_instance['content'] ) : '';
		$instance['location'] = ( ! empty( $new_instance['location'] ) ) ? sanitize_text_field( $new_instance['location'] ) : '';
		$instance['mail'] = ( ! empty( $new_instance['mail'] ) ) ? sanitize_text_field( $new_instance['mail'] ) : '';
		$instance['contact'] = ( ! empty( $new_instance['contact'] ) ) ? sanitize_text_field( $new_instance['contact'] ) : '';


		return $instance;
	}

} // class bizhunt_widget

// register bizhunt_widget widget
function register_bizhunt_widget() {
	register_widget( 'bizhunt_widget' );
}
add_action( 'widgets_init', 'register_bizhunt_widget' );




/**
 * Adds bizhunt_widget_recent widget.
 */
class bizhunt_widget_recent extends WP_Widget {

	/**
	 * Register widget with WordPress.
	 */
	function __construct() {
		parent::__construct(
			'bizhunt_widget_recent', // Base ID
			esc_html__( 'Widget Recent Post', 'bizhunt' ), // Name
			array( 'description' => esc_html__( 'A Bizhunt Widget Recent Post', 'bizhunt' ), ) // Args
		);
	}

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {
		echo $args['before_widget'];
		if ( ! empty( $instance['title'] ) ) {
		}
		?>	

		<?php 
        //Argument for WP query
		$arg = array( 
			'post_type' => 'post', 
			'posts_per_page' =>3, 
			'post_status' => 'publish', 
			'orderby' => 'date', 
			'order' => 'DESC' 
		); 
                $the_query = new WP_Query( $arg ); //Creating WP Query object
                if( $the_query->have_posts() ) { ?>

                	<div class="single-footer">
                		<h2 class="heading"><?php echo esc_html(  $instance['title'] ); ?></h2>
                		<?php while( $the_query->have_posts() ) { $the_query->the_post(); ?>
                			<div class="latest-news">
                				<?php if(has_post_thumbnail()):
                					?>
                					<a href="<?php the_permalink(); ?>"><?php the_post_thumbnail(); ?></a>
                					<?php
                				endif;
                				?>
                				<?php if(get_the_content()): ?>
                					<div class="news-content">
                						<a href="<?php the_permalink(); ?>">
                							<h5><?php the_title(); ?></h5>
                						</a>
                						<span> <?php echo get_the_date(); ?></span>
                					</div>
                				<?php endif; ?>
                			</div>
                		<?php } wp_reset_postdata(); ?>
                	</div>
                <?php } ?>

                <?php
                echo $args['after_widget'];
            }

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {
		$title = ! empty( $instance['title'] ) ? $instance['title'] : esc_html__( 'Recent Posts', 'bizhunt' );

		
		?>
		<p>
			<!-- Widget Title -->
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_attr_e( 'Title:', 'bizhunt' ); ?></label> 
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
		</p>
		<?php 
	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? sanitize_text_field( $new_instance['title'] ) : '';

		return $instance;
	}

} // class bizhunt_widget_recent

// register bizhunt_widget_recent widget
function register_bizhunt_widget_recent() {
	register_widget( 'bizhunt_widget_recent' );
}
add_action( 'widgets_init', 'register_bizhunt_widget_recent' );
?>